@@ -81,7 +81,7 @@ Rprintf("############ Warning - Priors turned off - use only for checking mlik v
        gsl_multimin_fminimizer *s;
      gsl_multimin_function F; 
  
-  double lower,upper,lower_f,upper_f;int found=0; double delta=0.0,new_f_min=0.0, finitestepsize_nm=0.0, increLogscale=0.0, best_Error=0.0,best_h=0.0;
+  double lower,upper,lower_f,upper_f;int found=0; double delta=0.0,new_f_min=0.0, increLogscale=0.0, best_Error=0.0,best_h=0.0;
  
   const gsl_min_fminimizer_type *T1;
   gsl_min_fminimizer *s1; 
@@ -266,7 +266,7 @@ Rprintf("############ Warning - Priors turned off - use only for checking mlik v
                                     status=GSL_FAILURE;} /** solution failed to achieve a value below h_epsabs **/                                                               
 	 
     finitestepsize=gsl_vector_get(s->x,0);/** get best fin.diff stepsize **/
-    finitestepsize_nm=finitestepsize;/** save nelder mead estimate */
+    /*finitestepsize_nm=finitestepsize;*/ /** save nelder mead estimate */
     dag->hessianError[nodeid]= s->fval;/** get fin.diff error **/
     
     gsl_multimin_fminimizer_free (s);
@@ -834,7 +834,7 @@ double compute_mlik_nm(const gsl_vector *finitestepsize_vec, void *params)
    gsl_matrix *hessgvalues=gparams->mattmp2;
    gsl_matrix *hessgvalues3pt=gparams->mattmp3;
    double gvalue=gparams->betafixed;
-   int status,sss;
+   int sss;
    double mydet;
    double logscore,logscore3pt;
    double finitestepsize=gsl_vector_get(finitestepsize_vec,0);
@@ -849,11 +849,11 @@ double compute_mlik_nm(const gsl_vector *finitestepsize_vec, void *params)
    
    /*for(i=0;i<hessgvalues3pt->size1;i++){for(j=0;j<hessgvalues3pt->size2;j++){Rprintf("%e ",gsl_matrix_get(hessgvalues3pt,i,j));}Rprintf("\n");}*/
    
-   status=gsl_linalg_LU_decomp(hessgvalues,perm,&sss);
+   /*status=*/gsl_linalg_LU_decomp(hessgvalues,perm,&sss);
    mydet=gsl_linalg_LU_lndet(hessgvalues);/** compute determinant but this might be a nan - overflow? gsl_linalg_LU_lndet*/
    logscore= -n*gvalue-0.5*mydet+(m/2.0)*log((2.0*M_PI)/n);/** this is the final value */
   
-   status=gsl_linalg_LU_decomp(hessgvalues3pt,perm,&sss);
+   /*status=*/gsl_linalg_LU_decomp(hessgvalues3pt,perm,&sss);
    mydet=gsl_linalg_LU_lndet(hessgvalues3pt);/** compute determinant but this might be a nan - overflow? gsl_linalg_LU_lndet*/
    logscore3pt= -n*gvalue-0.5*mydet+(m/2.0)*log((2.0*M_PI)/n);/** this is the final value */
    
@@ -879,7 +879,7 @@ double compute_mlik_brent(double finitestepsize, void *params)
    gsl_matrix *hessgvalues=gparams->mattmp2;
    gsl_matrix *hessgvalues3pt=gparams->mattmp3;
    double gvalue=gparams->betafixed;
-   int status,sss;
+   int sss;
    double mydet;
    double logscore,logscore3pt;
    double error_val=0.0;
@@ -895,11 +895,11 @@ double compute_mlik_brent(double finitestepsize, void *params)
    
    /*for(i=0;i<hessgvalues3pt->size1;i++){for(j=0;j<hessgvalues3pt->size2;j++){Rprintf("%e ",gsl_matrix_get(hessgvalues3pt,i,j));}Rprintf("\n");}*/
    
-   status=gsl_linalg_LU_decomp(hessgvalues,perm,&sss);
+   /*status=*/gsl_linalg_LU_decomp(hessgvalues,perm,&sss);
    mydet=gsl_linalg_LU_lndet(hessgvalues);/** compute determinant but this might be a nan - overflow? gsl_linalg_LU_lndet*/
    logscore= -n*gvalue-0.5*mydet+(m/2.0)*log((2.0*M_PI)/n);/** this is the final value */
   
-   status=gsl_linalg_LU_decomp(hessgvalues3pt,perm,&sss);
+   /*status=*/gsl_linalg_LU_decomp(hessgvalues3pt,perm,&sss);
    mydet=gsl_linalg_LU_lndet(hessgvalues3pt);/** compute determinant but this might be a nan - overflow? gsl_linalg_LU_lndet*/
    logscore3pt= -n*gvalue-0.5*mydet+(m/2.0)*log((2.0*M_PI)/n);/** this is the final value */
     
